@@ -365,6 +365,8 @@ insert_child_ginternal (SswSheetAxis *axis, GtkWidget *widget, guint index)
 {
   PRIV_DECL (axis);
 
+  g_assert (gtk_widget_get_realized (GTK_WIDGET (axis)));
+
   g_object_ref (widget);
 
   gtk_widget_set_parent_window (widget, priv->bin_window);
@@ -697,8 +699,6 @@ ensure_visible_widgets (SswSheetAxis *axis, gboolean force_reload)
           priv->bin_start_diff = start_widget_index * avg_widget_size;
         }
 
-      g_assert (priv->model_from >= 0);
-      g_assert (priv->model_to >= 0);
       g_assert (priv->model_from <= ssw_sheet_axis_get_extent (axis));
       g_assert (priv->model_to <= ssw_sheet_axis_get_extent (axis));
 
@@ -961,7 +961,6 @@ __realize (GtkWidget *w)
   GdkWindow *window;
 
   gtk_widget_get_allocation (w, &allocation);
-  gtk_widget_set_realized (w, TRUE);
 
   attributes.x = allocation.x;
   attributes.y = allocation.y;
@@ -972,12 +971,12 @@ __realize (GtkWidget *w)
     GDK_ALL_EVENTS_MASK;
   attributes.wclass = GDK_INPUT_OUTPUT;
 
-  window = gdk_window_new (gtk_widget_get_parent_window (w),
+  GdkWindow *pwin = gtk_widget_get_parent_window (w);
+  window = gdk_window_new (pwin,
                            &attributes, GDK_WA_X | GDK_WA_Y);
-  gdk_window_set_user_data (window, w);
+  gtk_widget_register_window (w, window);
   gtk_widget_set_window (w, window);
 
-
   priv->bin_window =
     gdk_window_new (window, &attributes, GDK_WA_X | GDK_WA_Y);
   gtk_widget_register_window (w, priv->bin_window);
@@ -993,6 +992,7 @@ __realize (GtkWidget *w)
     priv->resize_cursor = gdk_cursor_new_for_display (display, GDK_SB_V_DOUBLE_ARROW);
   else
     priv->resize_cursor = gdk_cursor_new_for_display (display, GDK_SB_H_DOUBLE_ARROW);
+  gtk_widget_set_realized (w, TRUE);
 }
 
 static void
@@ -1009,6 +1009,8 @@ __unrealize (GtkWidget *widget)
       priv->bin_window = NULL;
     }
 
+  gtk_widget_set_realized (widget, FALSE);
+
   GTK_WIDGET_CLASS (ssw_sheet_axis_parent_class)->unrealize (widget);
 }
 
@@ -1580,6 +1582,9 @@ static void
 ssw_sheet_axis_init (SswSheetAxis *axis)
 {
   PRIV_DECL (axis);
+
+  gtk_widget_set_has_window (GTK_WIDGET (axis), TRUE);
+
   GtkStyleContext *context = gtk_widget_get_style_context (GTK_WIDGET (axis));
 
   priv->adjustment = NULL;
